@@ -147,6 +147,12 @@ class RawInputsForHeatmap:
     raw_input_by_vizualizer_arg_name: Dict[str, npt.NDArray[np.float32]]
 
 
+@dataclass
+class SamplePreprocessResponse:
+    sample_ids: Union[npt.NDArray[np.float32], npt.NDArray[np.str_]]
+    preprocess_response: PreprocessResponse
+
+
 @dataclass
 class VisualizerHandlerData:
     name: str
